@@ -3,7 +3,7 @@ package Net::FullAuto::Cloud::fa_local;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2016  Brian M. Kelly
+#    Copyright © 2000-2015  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -22,7 +22,7 @@ package Net::FullAuto::Cloud::fa_local;
 #######################################################################
 
 
-our $VERSION='0.02';
+our $VERSION='0.01';
 
 
 use 5.005;
@@ -183,7 +183,7 @@ sub iset {
     ___     _ _   _       _              _                 _ _  _        _
    | __|  _| | | /_\ _  _| |_  |        | |   ___  __ __ _| | || |___ __| |_
    | _| || | | |/ _ \ || |  _/ | \      | |__/ _ \/ _/ _` | | __ / _ (_-<  _| 
-   |_| \_,_|_|_/_/ \_\_,_|\__\___/©  ON |____\___/\__\__,_|_|_||_\___/__/\__|
+   |_| \_,_|_|_/_/ \_\_,_|\__\___/c  ON |____\___/\__\__,_|_|_||_\___/__/\__|
 
    You are fully authenticated with FullAuto on LocalHost.
 
